@@ -11,7 +11,7 @@ use Readonly;
 
 Readonly::Array our @EXPORT_OK => qw(check_language);
 
-our $VERSION = 0.01;
+our $VERSION = 0.02;
 
 sub check_language {
 	my ($self, $key) = @_;
@@ -74,6 +74,49 @@ Returns undef.
          Language code '%s' isn't ISO 639-1 code.
          Language with ISO 639-1 code '%s' doesn't exist.
 
+=head1 EXAMPLE1
+
+=for comment filename=check_language_ok.pl
+
+ use strict;
+ use warnings;
+
+ use Mo::utils::Language qw(check_language);
+
+ my $self = {
+         'key' => 'en',
+ };
+ check_language($self, 'en');
+
+ # Print out.
+ print "ok\n";
+
+ # Output:
+ # ok
+
+=head1 EXAMPLE2
+
+=for comment filename=check_language_fail.pl
+
+ use strict;
+ use warnings;
+
+ use Error::Pure;
+ use Mo::utils::Language qw(check_language);
+
+ $Error::Pure::TYPE = 'Error';
+
+ my $self = {
+         'key' => 'xx',
+ };
+ check_language($self, 'key');
+
+ # Print out.
+ print "ok\n";
+
+ # Output like:
+ # #Error [...utils.pm:?] Language code 'xx' isn't ISO 639-1 code.
+
 =head1 DEPENDENCIES
 
 L<Error::Pure>,
@@ -94,6 +137,10 @@ Micro Objects. Mo is less.
 
 Mo utilities.
 
+=item L<Wikibase::Datatype::Utils>
+
+Wikibase datatype utilities.
+
 =back
 
 =head1 REPOSITORY
@@ -114,6 +161,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.01
+0.02
 
 =cut
